import {select, arc , geoPath , geoMercator, geoOrthographic, geoStereographic, 
        geoNaturalEarth1, zoom, event, scaleOrdinal, 
        schemeCategory10,
        schemeReds} from 'd3';

import {loadAndProcessData} from './loadAndProcessData';
import {colorLegend} from './colorLegend';

const svg = d3.select("svg");

const projection = geoMercator();
//const projection = geoOrthographic();
//const projection = geoStereographic();
//const projection = geoNaturalEarth1();

const g= svg.append('g');
const colorLegendGroup = 
      svg.append('g')
		.attr('transform',`translate(20,420)`);

const pathGenerator = geoPath().projection(projection);
g.append('path')
			.attr('class', 'globe')
			.attr('d', pathGenerator({type: 'Sphere'}));





function zoomed() { svg.attr('transform', d3.event.transform);}
svg.call(zoom().on('zoom', () => {g.attr('transform', event.transform)	}));

const colorScale = scaleOrdinal();


loadAndProcessData().then(
  countries=>
  {

    const colorValue = d => d.properties.income_grp;

    colorScale.domain(countries.features.map(colorValue))
  						.domain(colorScale.domain().filter(d => d != null).sort().reverse()) 
    					.range(schemeReds[colorScale.domain().length]) // range depending on number of categories in the data
    colorLegendGroup
		.call(colorLegend, {colorScale		 : colorScale, 
                        circleRadius	 : 4,
                        legendSpacing  : 15,
                        textOffset		 : 10,
                        numTicks 			 : 5
                       });
  const paths=g.selectAll('path').data(countries.features);
  paths.enter().append('path')
    .attr('class', 'country')
    .attr('d', d => pathGenerator(d))
    .attr('fill', d => colorScale(colorValue(d)))
    .append('title')
    .text( d => d.properties.name);
  }
  );


/*
World Atlas data (countries-110m.json) is in TopoJSON format.
D3 geo libraries can work with GeoJSON.
Therefore the TopoJSON-data needs to be converted to GeoJSON
in order to generate svg-paths using D3.
This is done with the geoPath-library.

In this script two generator functions are created:
1. projection: generate map projection
2. pathGenerator: convert TopoJSON to GeoJSON, then project it using the projection

*/






